==> rgeostat_0.1-3.tar.gz: rgeostat/src/krige_grid.h <==
#include <R.h>
#include <Rinternals.h>

void krige_grid(double *xsw,
	    double *ysw,
            double *xne,
	    double *yne,
            double *angle,
	    int *nx,
	    int *ny,                 
	    //                  nz=as.integer(nz),                 
	    double *dx,
	    double *dy,
	    double *xg,
            double *yg,
	    double *zg,
	    double *varg,
	    int *dog,
	    double *lon,
	    double *lat,
	    double *z,
	    int *extrap,
	    int *n,
	    int *covtype,
	    double *covpar,
	    //	    double *covmat=as.double(covmat),
            //      ldcov=as.integer(n),
            //      c0vec=double(n),
            //      ldc0vec=as.integer(n),
	    //      double *cov0,
            //      extcov=as.integer(0), # no external cov matrix
            int *trend,
	    int *ntrend,
	    double *rsearch,
	    int *nsearch,
	    int *nsmin,
	    int *nsmax,
            //      fwork=double(n*ntrend),
            //      ldfwrk=as.integer(n),
            //      f0work=double(ntrend),
            //      dist=double(n),
            //      indsnb=integer(n),
            //      indsna=integer(n),
            //      indsrt=integer(n),
            //      kwork=double((n+ntrend)*(n+ntrend)),
            //      nkwork=as.integer(n+ntrend),
            //      rhswork=double(n+ntrend),
            //      ipiv=integer(n+ntrend),
	    int *mode,
	    // mu=double(ntrend),
            //      lambda=double(n),
            //      ldlmbd=as.integer(n),
            int *bits,
	    int *ierr);

F77_NAME(krggrd)(double *xsw, 
		 double *ysw, 
		 double *xne, 
		 double *yne, 
		 double *angle, 
		 int *nx, 
		 int *ny, 
		 int *nz, 
		 double *dx, 
		 double *dy, 
		 double *xg, 
		 double *yg, 
		 double *zg, 
		 double *varg, 
		 int *dog, 
		 double *lon, 
		 double *lat, 
		 double *z, 
		 int *extrap, 
		 int *n, 
		 int *covtype, 
		 double *covpar, 
		 double *covmat, 
		 int *ldcov, 
		 double *c0vec, 
		 int *ldc0, 
		 double *cov0,
		 int *extcov, 
		 int *trend, 
		 int *ntrend, 
		 double *rsearch, 
		 int *nsearch, 
		 int *nsmin, 
		 int *nsmax, 
		 double *fwork, 
		 int *ldfwrk, 
		 double *f0work, 
		 double *dist, 
		 int *indsnb, 
		 int *indsna, 
		 int *indsrt, 
		 double *kwork, 
		 int *nkwork, 
		 double *rhswork, 
		 int *ipiv, 
		 int *mode, 
		 double *mu, 
		 double *lambda, 
		 int *ldlmbd, 
		 int *bits, 
		 int *ierr);

==> rgeostat_0.1-4.tar.gz: rgeostat/src/krige_grid.h <==
#include <R.h>
#include <Rinternals.h>

void krige_grid(double *xsw,
	    double *ysw,
            double *xne,
	    double *yne,
            double *angle,
	    int *nx,
	    int *ny,                 
	    double *dx,
	    double *dy,
	    double *xg,
            double *yg,
	    double *zg,
	    double *varg,
	    int *dog,
	    double *lon,
	    double *lat,
	    double *z,
	    int *extrap,
	    int *n,
	    int *covtype,
	    double *covpar,
	    double *covmat,
		int *ldcov,
		int *extcov,
            int *trend,
	    int *ntrend,
	    double *rsearch,
	    int *nsearch,
	    int *nsmin,
	    int *nsmax,
	    int *mode,
            double *mu,
            double *lambda,
            int *bits,
		int *retlm,
	    int *ierr);

void krige_grid__(double *xsw,
	    double *ysw,
            double *xne,
	    double *yne,
            double *angle,
	    int *nx,
	    int *ny,                 
	    double *dx,
	    double *dy,
	    double *xg,
            double *yg,
	    double *zg,
	    double *varg,
	    int *dog,
	    double *lon,
	    double *lat,
	    double *z,
	    int *extrap,
	    int *n,
	    int *covtype,
	    double *covpar,
	    double *covmat,
		int *ldcov,
		int *extcov,
            int *trend,
	    int *ntrend,
	    double *rsearch,
	    int *nsearch,
	    int *nsmin,
	    int *nsmax,
	    int *mode,
            double *mu,
            double *lambda,
            int *bits,
		  int *retlm,
	    int *ierr);

void F77_NAME(krggrd)(double *xsw, 
		 double *ysw, 
		 double *xne, 
		 double *yne, 
		 double *angle, 
		 int *nx, 
		 int *ny, 
		 int *nz, 
		 double *dx, 
		 double *dy, 
		 double *xg, 
		 double *yg, 
		 double *zg, 
		 double *varg, 
		 int *dog, 
		 double *lon, 
		 double *lat, 
		 double *z, 
		 int *extrap, 
		 int *n, 
		 int *covtype, 
		 double *covpar, 
		 double *covmat, 
		 int *ldcov, 
		 double *c0vec, 
		 int *ldc0, 
		 double *cov0,
		 int *extcov, 
		 int *trend, 
		 int *ntrend, 
		 double *rsearch, 
		 int *nsearch, 
		 int *nsmin, 
		 int *nsmax, 
		 double *fwork, 
		 int *ldfwrk, 
		 double *f0work, 
		 double *dist, 
		 int *indsnb, 
		 int *indsna, 
		 int *indsrt, 
		 double *kwork, 
		 int *nkwork, 
		 double *rhswork, 
		 int *ipiv, 
		 int *mode, 
		 double *mu, 
		 int *ldmu, 
		 double *lambda, 
		 int *ldlmbd, 
		 int *bits, 
		      int *retlm,
		 int *ierr);
